OpenIosSettingPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • OpenIosSettingPlatform
Implementers

Constructors

OpenIosSettingPlatform()
Constructs a OpenIosSettingPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSettingHome() Future<void>
打开 iOS 设置首页
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance OpenIosSettingPlatform
The default instance of OpenIosSettingPlatform to use.
getter/setter pair